@@ -20,6 +20,7 @@
 #define SERVICEOPERATIONSTATUS_P
 
 #include <QObject>
+#include <QPointer>
 
 #include "plasma/service.h"
 
@@ -52,7 +53,7 @@ class ServiceOperationStatus : public QObject
     Q_PROPERTY(bool enabled READ isEnabled WRITE setEnabled NOTIFY enabledChanged)
 
 public:
-    ServiceOperationStatus(QObject *parent = 0);
+    explicit ServiceOperationStatus(QObject *parent = nullptr);
     ~ServiceOperationStatus();
 
     void setService(Plasma::Service *service);
@@ -73,7 +74,7 @@ private Q_SLOTS:
     void updateStatus();
 
 private:
-    QWeakPointer<Plasma::Service> m_service;
+    QPointer<Plasma::Service> m_service;
     QString m_operation;
     bool m_enabled;
 };
