@@ -1,19 +1,33 @@
 /*
-    SPDX-FileCopyrightText: 2007 Aaron Seigo <aseigo@kde.org>
-    SPDX-FileCopyrightText: 2008 Ménard Alexis <darktears31@gmail.com>
-
-    SPDX-License-Identifier: LGPL-2.0-or-later
-*/
+ *   Copyright 2007 by Aaron Seigo <aseigo@kde.org>
+ *   Copyright 2008 by Ménard Alexis <darktears31@gmail.com>
+ *
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU Library General Public License as
+ *   published by the Free Software Foundation; either version 2, or
+ *   (at your option) any later version.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details
+ *
+ *   You should have received a copy of the GNU Library General Public
+ *   License along with this program; if not, write to the
+ *   Free Software Foundation, Inc.,
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ */
 
 #ifndef CONTAINMENT_P_H
 #define CONTAINMENT_P_H
 
+#include <kactioncollection.h>
 #include <QSet>
 
-#include "applet.h"
-#include "containmentactions.h"
-#include "corona.h"
 #include "plasma.h"
+#include "applet.h"
+#include "corona.h"
+#include "containmentactions.h"
 
 class KJob;
 
@@ -22,13 +36,9 @@ namespace KIO
 class Job;
 }
 
-namespace KActivities
-{
-class Info;
-}
-
 namespace Plasma
 {
+
 class Containment;
 
 class ContainmentPrivate
@@ -45,13 +55,13 @@ public:
      * constraint services common to all containments. Containments should still
      * implement their own constraintsEvent method
      */
-    void containmentConstraintsEvent(Applet::Constraints constraints);
+    void containmentConstraintsEvent(Plasma::Types::Constraints constraints);
 
     bool isPanelContainment() const;
     void appletDeleted(Applet *);
     void configChanged();
 
-    Applet *createApplet(const QString &name, const QVariantList &args = QVariantList(), uint id = 0, const QRectF &geometryHint = QRectF());
+    Applet *createApplet(const QString &name, const QVariantList &args = QVariantList(), uint id = 0);
 
     /**
      * FIXME: this should completely go from here
@@ -63,31 +73,27 @@ public:
     /**
      * add the regular actions & keyboard shortcuts onto Applet's collection
      */
-    static void addDefaultActions(QMap<QString, QAction *> &actions, Containment *c = nullptr, Corona *cor = nullptr);
+    static void addDefaultActions(KActionCollection *actions, Containment *c = nullptr);
 
     void setUiReady();
     void setStarted();
-    void appletLoaded(Applet *applet);
+    void appletLoaded(Applet* applet);
 
     Containment *q;
     Types::FormFactor formFactor;
     Types::Location location;
-    Types::ContainmentDisplayHints containmentDisplayHints = Types::NoContainmentDisplayHint;
-
-    KActivities::Info *activityInfo;
     QList<Applet *> applets;
-    // Applets still considered not ready
-    QSet<Applet *> loadingApplets;
-    QString wallpaperPlugin;
-    QObject *wallpaperGraphicsObject = nullptr;
+    //Applets still considered not ready
+    QSet <Applet *> loadingApplets;
+    QString wallpaper;
     QHash<QString, ContainmentActions *> localActionPlugins;
     int lastScreen;
     QString activityId;
-    Containment::Type type;
+    Types::ContainmentType type;
     bool uiReady : 1;
     bool appletsUiReady : 1;
 
-    static const char defaultWallpaperPlugin[];
+    static const char defaultWallpaper[];
 };
 
 } // Plasma namespace
